"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const custom_resources_1 = require("@aws-cdk/custom-resources");
/**
 * An AwsCustomResource which raises an error on instantiation
 * if any action specified in its calls doesn't exist in the SDK
 */
class CheckedAwsCustomResource extends custom_resources_1.AwsCustomResource {
    constructor(scope, id, props) {
        checkCall(props.onCreate);
        checkCall(props.onUpdate);
        checkCall(props.onDelete);
        super(scope, id, props);
    }
}
exports.CheckedAwsCustomResource = CheckedAwsCustomResource;
/**
 * Raise an error if AwsSdkCall references an SDK method which does not exist
 * @param call The AwsSdkCall to check
 */
function checkCall(call) {
    if (!call) {
        return;
    }
    if (typeof AWS[call.service] !== "function") {
        throw new Error(`${call.service} is not a valid SDK service`);
    }
    const awsService = new AWS[call.service](call.apiVersion && { apiVersion: call.apiVersion });
    if (typeof awsService[call.action] !== "function") {
        throw new Error(`${call.action} is not a function in AWS.${call.service}`);
    }
}
