"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("@aws-cdk/assert");
const core_1 = require("@aws-cdk/core");
const index_1 = require("../src/index");
test("test successful init", () => {
    // GIVEN
    const stack = new core_1.Stack();
    const props = {
        onCreate: {
            service: "RDS",
            action: "modifyDBCluster",
            parameters: {},
            physicalResourceId: `resourceId`
        }
    };
    // WHEN
    new index_1.CheckedAwsCustomResource(stack, "foo", props);
    // THEN
    assert_1.expect(stack).to(assert_1.haveResource("Custom::AWS"));
});
test("test bad action name", () => {
    // GIVEN
    const stack = new core_1.Stack();
    const props = {
        onCreate: {
            service: "RDS",
            action: "ModifyDBCluster",
            parameters: {},
            physicalResourceId: `resourceId`
        }
    };
    expect(() => {
        // WHEN
        new index_1.CheckedAwsCustomResource(stack, "foo", props);
        // THEN
    }).toThrowError("ModifyDBCluster");
});
test("test bad service name", () => {
    // GIVEN
    const stack = new core_1.Stack();
    const props = {
        onCreate: {
            service: "FooBar",
            action: "modifyDBCluster",
            parameters: {},
            physicalResourceId: `resourceId`
        }
    };
    expect(() => {
        // WHEN
        new index_1.CheckedAwsCustomResource(stack, "foo", props);
        // THEN
    }).toThrowError("FooBar");
});
